"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.plugin = void 0;
const framework_core_1 = require("@cloudbase/framework-core");
const fs_extra_1 = __importDefault(require("fs-extra"));
const axios_1 = __importDefault(require("axios"));
const compressing_1 = __importDefault(require("compressing"));
const path_1 = __importDefault(require("path"));
const os_1 = __importDefault(require("os"));
const PLUGIN_DIR = path_1.default.join(os_1.default.homedir(), 'cloudbase-framework/registry/node_modules/@cloudbase/framework-plugin-low-code');
class LowCodeIntallerPlugin extends framework_core_1.Plugin {
    constructor(name, api, inputs) {
        super(name, api, inputs);
        this.name = name;
        this.api = api;
        this.inputs = inputs;
        this._inputs = inputs;
    }
    _subPluginConstructor() {
        return __awaiter(this, void 0, void 0, function* () {
            yield loadLowCodePlugin(PLUGIN_DIR);
            const { plugin: LowcodePlugin } = require(PLUGIN_DIR);
            this._lowcodePlugin = new LowcodePlugin('lowcode', this.api, this._inputs);
        });
    }
    init() {
        return __awaiter(this, void 0, void 0, function* () { });
    }
    run() {
        return __awaiter(this, void 0, void 0, function* () { });
    }
    remove() {
        return __awaiter(this, void 0, void 0, function* () { });
    }
    genCode() {
        return __awaiter(this, void 0, void 0, function* () { });
    }
    build() {
        return __awaiter(this, void 0, void 0, function* () {
            yield this._subPluginConstructor();
            yield this._lowcodePlugin.init();
            return this._lowcodePlugin.build();
        });
    }
    compile() {
        return __awaiter(this, void 0, void 0, function* () {
            return this._lowcodePlugin.compile();
        });
    }
    deploy() {
        return __awaiter(this, void 0, void 0, function* () {
            return this._lowcodePlugin.deploy();
        });
    }
}
function loadLowCodePlugin(pluginDir) {
    return __awaiter(this, void 0, void 0, function* () {
        const source = 'https://ci-source-1303824488.cos.ap-shanghai.myqcloud.com/presetResource/plugin.tar.gz';
        fs_extra_1.default.ensureDirSync(pluginDir);
        fs_extra_1.default.emptyDirSync(pluginDir);
        try {
            let response = yield (0, axios_1.default)({
                url: source,
                responseType: 'stream',
            });
            yield fs_extra_1.default.ensureDir(pluginDir);
            const tag = `uncompress ${source}`;
            console.time(tag);
            yield compressing_1.default.tgz.uncompress(response.data, pluginDir);
            console.timeEnd(tag);
        }
        catch (e) {
            console.error(`Fail to download lowcode plugin package ${source}`, e);
            throw e;
        }
    });
}
exports.plugin = LowCodeIntallerPlugin;
